@@ -27,76 +27,89 @@ Cat::Cat(S4 cat_df) : questionSet(cat_df),
                       estimator(createEstimator(cat_df, integrator, questionSet)),
                       selector(createSelector(cat_df.slot("selection"), questionSet, *estimator, prior)){}
 
-std::vector<bool> Cat::checkStopRules() {
-  std::vector<bool> all_thresholds;
-  std::vector<bool> all_overrides;
-  
+bool Cat::checkStopRules() { 
   double SE_est = estimator->estimateSE(prior);
-  double theta_est = estimator->estimateTheta(prior);
-  
-  // Checking whether or not user wants each rule implemented, then performing the check
-  if (! std::isnan(checkRules.lengthThreshold)){
-    bool answer_lengthTheshold = questionSet.applicable_rows.size() >= checkRules.lengthThreshold ? true : false;
-    all_thresholds.push_back(answer_lengthTheshold);
-  } else { }
 
-  if (! std::isnan(checkRules.lengthOverride)){
-    bool answer_lengthOverride = questionSet.applicable_rows.size() < checkRules.lengthOverride ? true : false;
-    all_overrides.push_back(answer_lengthOverride);
-  } else { }
+  if(noneOfOverrides(SE_est))
+  {
+    return anyOfThresholds(SE_est);
+  }
+  return false;  
+}
 
-  if (! std::isnan(checkRules.seThreshold)){
-    bool answer_seThreshold = SE_est < checkRules.seThreshold ? true : false;
-    all_thresholds.push_back(answer_seThreshold);
-  } else { }
+bool Cat::anyOfThresholds(double se)
+{  
+  if (! std::isnan(checkRules.lengthThreshold))
+  {
+    if(questionSet.applicable_rows.size() >= checkRules.lengthThreshold)
+    {
+      return true;
+    }
+  }
+
+  if (! std::isnan(checkRules.seThreshold))
+  {
+    if(se < checkRules.seThreshold )
+    {
+      return true;
+    }
+  }
 
   if (! std::isnan(checkRules.gainThreshold)){
-    std::vector<bool> all_gainThreshold;
-    for (auto item : questionSet.nonapplicable_rows) {
-      double gain = std::abs(SE_est - std::pow(expectedPV(item), 0.5));
-      bool item_threshold = gain < checkRules.gainThreshold ? true : false;
-      all_gainThreshold.push_back(item_threshold);
-    }
-    bool answer_gainThreshold = std::all_of(all_gainThreshold.begin(), all_gainThreshold.end(), [](bool v) { return v; });
-    all_thresholds.push_back(answer_gainThreshold);
-  } else { }
+    bool answer_gainThreshold  = std::all_of(questionSet.nonapplicable_rows.begin(), questionSet.nonapplicable_rows.end(), [&](int item)
+    {
+        double gain = std::abs(se - std::pow(expectedPV(item), 0.5));
+        return gain < checkRules.gainThreshold;
+    });
 
-  if (! std::isnan(checkRules.gainOverride)){
-    std::vector<bool> all_gainOverride;
-    for (auto item : questionSet.nonapplicable_rows) {
-      double gain = std::abs(SE_est - std::pow(expectedPV(item), 0.5));
-      bool item_override = gain >= checkRules.gainOverride ? true : false;
-      all_gainOverride.push_back(item_override);
+    if(answer_gainThreshold)
+    {
+      return true;
     }
-    bool answer_gainOverride  = std::all_of(all_gainOverride.begin(), all_gainOverride.end(), [](bool v) { return v; });
-    all_overrides.push_back(answer_gainOverride);
-  } else { }
+  }
+
 
   if (! std::isnan(checkRules.infoThreshold)){
-    std::vector<bool> all_infoThreshold;
-    for (auto item : questionSet.nonapplicable_rows) {
-      double info = estimator->fisherInf(theta_est, item);
-      bool item_answer = info < checkRules.infoThreshold ? true : false;
-      all_infoThreshold.push_back(item_answer);
-    }
-    bool answer_infoThreshold  = std::all_of(all_infoThreshold.begin(), all_infoThreshold.end(), [](bool v) { return v; });
-    all_thresholds.push_back(answer_infoThreshold);
-  } else { }
-  
+    double theta = estimator->estimateTheta(prior);
+    bool answer_infoThreshold  = std::all_of(questionSet.nonapplicable_rows.begin(), questionSet.nonapplicable_rows.end(), [&](int item)
+    {
+        double info = estimator->fisherInf(theta, item);
+        return info < checkRules.infoThreshold;
+    });
 
-  //had to do these excessive measures to get return value into a vector
-  std::vector<bool> stop;
-  
-  if(all_thresholds.empty() && all_overrides.empty()){
-    stop.push_back(false);
-  } else {
-    bool any_thresholds_true = std::any_of(all_thresholds.begin(), all_thresholds.end(), [](bool v) { return v; });
-    bool all_overrides_false = std::all_of(all_overrides.begin(), all_overrides.end(), [](bool v) { return !v; });
-  
-    bool answer = any_thresholds_true && all_overrides_false ? true : false;
-    stop.push_back(answer);
+    if(answer_infoThreshold)
+    {
+      return true;
+    }
   }
-  return stop; 
+   
+  return false;
+}
+
+bool Cat::noneOfOverrides(double se)
+{
+  if (! std::isnan(checkRules.lengthOverride))
+  {
+    if(questionSet.applicable_rows.size() < checkRules.lengthOverride)
+    {
+      return false;
+    }
+  }
+
+  if (! std::isnan(checkRules.gainOverride))
+  {
+    bool answer_gainOverride  = std::all_of(questionSet.nonapplicable_rows.begin(), questionSet.nonapplicable_rows.end(), [&](int item)
+    {
+        double gain = std::abs(se - std::pow(expectedPV(item), 0.5));
+        return gain >= checkRules.gainOverride;
+    });
+
+    if(answer_gainOverride)
+    {
+      return false;
+    }
+  }
+  return true;
 }
 
 double Cat::likelihood(double theta) {
@@ -156,18 +169,81 @@ List Cat::lookAhead(int item) {
     Selection selection = selector->selectItem();
     items.push_back(selection.item + 1);
     response_options.push_back(questionSet.answers.at(item));
-	}
+  }
   
   questionSet.nonapplicable_rows.push_back(item); // add item back to unanswered q's
-	questionSet.applicable_rows.pop_back(); // remove item from answered q's
-	questionSet.answers.at(item) = NA_INTEGER; // remove answer
-	  
-	DataFrame all_estimates = Rcpp::DataFrame::create(Named("response_option") = response_options,
+  questionSet.applicable_rows.pop_back(); // remove item from answered q's
+  questionSet.answers.at(item) = NA_INTEGER; // remove answer
+    
+  DataFrame all_estimates = Rcpp::DataFrame::create(Named("response_option") = response_options,
                                                    Named("next_item") = items);
-	return Rcpp::List::create(Named("estimates") = all_estimates);
+  return Rcpp::List::create(Named("estimates") = all_estimates);
 }
 
+NumericVector Cat::estimateThetas(DataFrame& responses)
+{
+  if(responses.ncol() != questionSet.question_names.size())
+  {
+    throw std::domain_error("number of questions doesnt match with catObj");
+  }
 
+  size_t nrow = responses.nrow();
+  NumericVector thetas;
+  thetas = static_cast<NumericVector>(no_init(nrow));
+
+  for(size_t row = 0; row != nrow; ++row)
+  {
+    questionSet.reset_answers(responses, row);
+    thetas[row] = estimateTheta();
+  }
+
+  return thetas;
+}
+
+NumericVector Cat::simulateThetas(DataFrame& responses)
+{
+  if(std::isnan(checkRules.lengthThreshold) && std::isnan(checkRules.seThreshold) &&
+   std::isnan(checkRules.infoThreshold) && std::isnan(checkRules.gainThreshold) )
+  {
+    throw std::domain_error("Need to specify stopping rule(s) in Cat object.");
+  }
+
+  if(!questionSet.applicable_rows.empty())
+  {
+    throw std::domain_error("All answers Cat object should be NA.");
+  }
+  
+
+  size_t nrow = responses.nrow();
+  NumericVector thetas;
+  thetas = static_cast<NumericVector>(no_init(nrow));
+
+  auto answers = questionSet.answers;
+
+  for(size_t row = 0; row != nrow; ++row)
+  {
+    while(!questionSet.nonapplicable_rows.empty() && !(checkStopRules()))
+    {
+      Selection selection = selector->selectItem();
+      Rcpp::IntegerVector col = responses[selection.item];
+      if(col[row] == NA_INTEGER)
+      {
+        questionSet.reset_answer(selection.item, -1);
+      }
+      else
+      {
+        questionSet.reset_answer(selection.item, col[row]);
+      }
+    }
+
+    // FIX ME: checkStopRules already computes theta
+    thetas[row] = estimateTheta();
+
+    questionSet.reset_answers(answers);
+  }
+
+  return thetas;
+}
 
 
 double Cat::d1LL(double theta, bool use_prior) {
