@@ -12,7 +12,9 @@ public:
 	virtual EstimationType getEstimationType() const override;
 
 	virtual double estimateTheta(Prior prior) override;
+	virtual double estimateTheta(Prior prior, size_t question, int answer) override;
 	
 	virtual double estimateSE(Prior prior) override;
+	virtual double estimateSE(Prior prior, size_t question, int answer) override;
 
 };
