@@ -397,6 +397,109 @@ double estimateTheta(S4 catObj) {
 }
 
 
+
+
+
+//' Estimates of Ability Parameters for a Dataset of Response Profiles
+//'
+//' Estimates the expected value of the ability parameter \eqn{\theta}, conditioned on the observed answers, prior, and the item parameters
+//' for complete response profiles for a dataset of respondents.
+//'
+//' @param catObj An object of class \code{Cat}
+//' @param responses A dataframe of complete response profiles
+//'
+//' @return The function \code{estimateThetas} returns a vector of the expected values of the respondents' ability parameters.
+//'
+//' @details
+//' 
+//' Estimation approach is specified in \code{estimation} slot of \code{Cat} object.
+//' 
+//' The expected a posteriori approach is used when \code{estimation} slot is \code{"EAP"}.  This method involves integration.  See \strong{Note} for more information.
+//' 
+//' The modal a posteriori approach is used when \code{estimation} slot is \code{"MAP"}.  This method is only available using the normal prior distribution.
+//' 
+//' The maximum likelihood approach is used when \code{estimation} slot is \code{"MLE"}.  When the likelihood is undefined,
+//' the MAP or EAP method will be used, determined by what is specified in the \code{estimationDefault} slot in \code{Cat} object.
+//' 
+//' The weighted maximum likelihood approach is used when \code{estimation} slot is \code{"WLE"}.
+//' Estimating \eqn{\theta} requires root finding with the ``Brent'' method in the GNU Scientific
+//'  Library (GSL) with initial search interval of \code{[-5,5]}.
+//' 
+//' @examples
+//'## Loading ltm Cat object
+//'data(ltm_cat)
+//'
+//'## Set different estimation procedures and estimate ability parameter
+//'data(npi)
+//'setEstimation(ltm_cat) <- "EAP"
+//'estimateThetas(ltm_cat, responses = npi[1:25, ])
+//'
+//' 
+//' @author Haley Acevedo, Ryden Butler, Josh W. Cutler, Matt Malis, Jacob M. Montgomery,
+//'  Tom Wilkinson, Erin Rossiter, Min Hee Seo, Alex Weil 
+//'  
+//' @note This function is to allow users to access the internal functions of the package. During item selection, all calculations are done in compiled \code{C++} code.
+//' 
+//' This function uses adaptive quadrature methods from the GNU Scientific
+//'  Library (GSL) to approximate single-dimensional
+//'  integrals with high accuracy.  The bounds of integration are determined by the
+//'  \code{lowerBound} and \code{upperBound} slots of the \code{Cat} object.
+//' 
+//' @seealso \code{\link{Cat-class}}, \code{\link{estimateTheta}}
+//' @export
+// [[Rcpp::export]]
+NumericVector estimateThetas(S4 catObj, DataFrame responses){
+	return Cat(catObj).estimateThetas(responses);
+}
+
+
+
+
+
+//' Simulates Estimates of Ability Parameters for a Dataset of Response Profiles
+//'
+//' Given a set of stopping rules and complete response profiles for a dataset of respondents,
+//' simulates the expected value of the ability parameter \eqn{\theta} as though an adaptive 
+//' battery were provided
+//'
+//' @param catObj An object of class \code{Cat} with stopping rule(s) specified
+//' @param responses A dataframe of complete response profiles
+//'
+//' @return The function \code{simulateThetas} returns a vector of the expected values of the respondents' ability parameters
+//' as though the respondents were given an adaptive battery.  Given the item selection criterion specified in the \code{Cat} object,
+//'  this function selects an item, "administers" the item to the respondent, and records their answer from the dataframe provided in
+//'  the \code{response} parameter of the function.  This process continues until stopping rule(s) specified in the \code{Cat} object are met for each respondent.  The function returns a final estimate of the ability parameter \eqn{\theta}
+//'  for each respondent.
+//'  
+//'
+//' 
+//' @examples
+//'## Loading ltm Cat object
+//'data(ltm_cat)
+//'
+//'## Set estimation, selection, and stopping rule
+//'data(npi)
+//'setEstimation(ltm_cat) <- "EAP"
+//'setSelection(ltm_cat) <- "EPV"
+//'setLengthThreshold(ltm_cat) <- 3
+//'
+//'## Simulate theta by asking 3 questions adaptively for the first 25 respondents
+//'simulateThetas(ltm_cat, responses = npi[1:25, ])
+//'
+//' 
+//' @author Haley Acevedo, Ryden Butler, Josh W. Cutler, Matt Malis, Jacob M. Montgomery,
+//'  Tom Wilkinson, Erin Rossiter, Min Hee Seo, Alex Weil 
+//'  
+//' @note This function is to allow users to access the internal functions of the package. During item selection, all calculations are done in compiled \code{C++} code.
+//' 
+//' @seealso \code{\link{Cat-class}}, \code{\link{estimateThetas}}, \code{\link{checkStopRules}}
+//' @export
+// [[Rcpp::export]]
+NumericVector simulateThetas(S4 catObj, DataFrame responses){
+	return Cat(catObj).simulateThetas(responses);
+}
+
+
 //' Observed Information
 //'
 //' Calculates the observed information of the likelihood of a respondent's ability \eqn{\theta} for a given \code{item}.
@@ -1052,8 +1155,7 @@ List lookAhead(S4 catObj, int item) {
 //' @export
 // [[Rcpp::export]]
 bool checkStopRules(S4 catObj) {
-	std::vector<bool> answer = Cat(catObj).checkStopRules();
-  return answer[0];
+  return Cat(catObj).checkStopRules();
 }
 
 
